# -*- coding: utf-8 -*-
# Filename: baseGui.py 


from PyQt4.QtGui import *
from PyQt4.QtCore import Qt, SIGNAL, SLOT


class baseGui(QTextBrowser):

	def __init__(self, *args):
		QTextBrowser.__init__(self, None)
		self.setAlignment(Qt.AlignCenter)
		self.setFrameShape(QFrame.NoFrame)
		self.setLineWrapMode(QTextEdit.NoWrap)
		self.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
		self.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
		self.setAutoFillBackground(True)
        	self.viewport().setMouseTracking(False)
        	self.setWindowIcon(QIcon('./icon/lrcShow-X.png'))
		self.initMenu()
		self.initSettingMenuBar()
		self.initIconTray()

		self.quitShortcut = QShortcut(QKeySequence('Ctrl+Q'), self)
		self.nextTrackShortcut = QShortcut(QKeySequence('Ctrl+N'), self)
		self.prevTrackShortcut = QShortcut(QKeySequence('Ctrl+V'), self)
		self.pauseTrackShortcut = QShortcut(QKeySequence('Space'), self)
		self.stopTrackShortcut = QShortcut(QKeySequence('Ctrl+S'), self)
		
		self.connect(self.iconTray,SIGNAL("activated(QSystemTrayIcon::ActivationReason)"),self.iconTrayAction)
	
	def initColor(self, t, backgroundColor, textColor, highlightedTextColor):# to set colors
		if(t == 'yes'):
			backgroundColor.setAlpha(0)
		else:
			backgroundColor.setAlpha(255)
		pl = QPalette()
		pl.setColor(QPalette.Window, backgroundColor)
		pl.setColor(QPalette.Base, backgroundColor)
		pl.setColor(QPalette.Text, textColor)
		pl.setColor(QPalette.Highlight, backgroundColor)
		pl.setColor(QPalette.HighlightedText, highlightedTextColor)
		self.setPalette(pl)
		self.update()
	
	def iconTrayAction(self, reason):
		if(reason == QSystemTrayIcon.Trigger):
			if(self.isHidden()):
				self.show()
			else:
				self.hide()
	
	def initMenu(self): # init the right click menu
		self.myMenu = QMenu()
		
		self.trackInfoAction = QAction(QIcon('./icon/info.png'), _('Track information...'), self)
		self.myMenu.addAction(self.trackInfoAction)
		
		self.lrcAdjustMenu = QMenu()
		self.lrcAdjustMenu.setTitle(_('Adjust offset'))
		self.lrcAdjustMenu.setIcon(QIcon('./icon/adjust.png'))
		self.lrcAdjustMenu_delayAction = QAction(QIcon('./icon/backward.png'), _('Delay the lrc 0.2sec'), self)
		self.lrcAdjustMenu_advancedAction = QAction(QIcon('./icon/forward.png'), _('Advance the lrc 0.2sec'), self)
		self.lrcAdjustMenu_saveToFileAction = QAction(QIcon('./icon/save.png'), _('Save offset'), self)
		self.lrcAdjustMenu.addAction(self.lrcAdjustMenu_delayAction)
		self.lrcAdjustMenu.addAction(self.lrcAdjustMenu_advancedAction)
		self.lrcAdjustMenu.addSeparator()
		self.lrcAdjustMenu.addAction(self.lrcAdjustMenu_saveToFileAction)
		self.myMenu.addMenu(self.lrcAdjustMenu)
		
		self.playerControlMenu = QMenu()
		self.playerControlMenu.setTitle(_('Player control'))
		self.playerControlMenu.setIcon(QIcon('./icon/player.png'))
		self.playerControlMenu_playorpauseAction = QAction(QIcon('./icon/player_play.png'), _('Play'), self)
		self.playerControlMenu_stopAction = QAction(QIcon('./icon/player_stop.png'), _('Stop'), self)
		self.playerControlMenu_prevAction = QAction(QIcon('./icon/player_back.png'), _('Prev'), self)
		self.playerControlMenu_nextAction = QAction(QIcon('./icon/player_next.png'), _('Next'), self)
		self.playerControlMenu.addAction(self.playerControlMenu_playorpauseAction)
		self.playerControlMenu.addAction(self.playerControlMenu_stopAction)
		self.playerControlMenu.addAction(self.playerControlMenu_prevAction)
		self.playerControlMenu.addAction(self.playerControlMenu_nextAction)
		self.myMenu.addMenu(self.playerControlMenu)
		
		self.colorMenu = QMenu()
		self.colorMenu.setTitle(_('Set colors'))
		self.colorMenu.setIcon(QIcon('./icon/colors.png'))
		self.colorMenu_backAction = QAction(QIcon('./icon/background.png'), _('Set background color...'), self)
		self.colorMenu_foreAction = QAction(QIcon('./icon/fontcolor.png'), _('Set font color...'), self)
		self.colorMenu_lightAction = QAction(QIcon('./icon/highlight.png'), _('Set highlight color...'), self)
		self.colorMenu_defaultAction = QAction(QIcon('./icon/undo.png'), _('Back to default colors'), self)
		self.colorMenu.addAction(self.colorMenu_backAction)
		self.colorMenu.addAction(self.colorMenu_foreAction)
		self.colorMenu.addAction(self.colorMenu_lightAction)
		self.colorMenu.addSeparator()
		self.colorMenu.addAction(self.colorMenu_defaultAction)
		self.myMenu.addMenu(self.colorMenu)
		
		self.setFontAction = QAction(QIcon('./icon/font.png'), _('Set fonts...'), self)
		self.myMenu.addAction(self.setFontAction)
		
		self.setLineAction = QAction(QIcon('./icon/line.png'), _('Set show-line...'), self)
		self.myMenu.addAction(self.setLineAction)
		
		self.downloadMenu = QMenu()
		self.downloadMenu.setTitle(_('Auto download'))
		self.downloadMenu.setIcon(QIcon('./icon/download.png'))
		self.downloadMenu_actionGroup = QActionGroup(self)
		self.downloadMenu_yesAction = QAction(_('Yes'), self)
		self.downloadMenu_yesAction.setCheckable(True)
		self.downloadMenu_noAction = QAction(_('No'), self)
		self.downloadMenu_noAction.setCheckable(True)
		self.downloadMenu_actionGroup.addAction(self.downloadMenu_yesAction)
		self.downloadMenu_actionGroup.addAction(self.downloadMenu_noAction)
		
		self.downloadMenu_thisAction = QAction(_('Just this'), self)
		self.downloadMenu.addActions(self.downloadMenu_actionGroup.actions())
		self.downloadMenu.addSeparator()
		self.downloadMenu.addAction(self.downloadMenu_thisAction)
		self.myMenu.addMenu(self.downloadMenu)
		
		self.displayMenu = QMenu()
		self.displayMenu.setTitle(_('Set display mode'))
		self.displayMenu.setIcon(QIcon('./icon/screen.png'))
		self.displayMenu_actionGroup = QActionGroup(self)
		self.displayMenu_normalAction = QAction(QIcon('./icon/normal.png'), _('Normal'), self)
		self.displayMenu_normalAction.setCheckable(True)
		self.displayMenu_fullscreenAction = QAction(QIcon('./icon/fullscreen.png'), _('Fullscreen'), self)
		self.displayMenu_fullscreenAction.setCheckable(True)
		self.displayMenu_osdAction = QAction(QIcon('./icon/osd.png'),_('OSD'), self)
		self.displayMenu_osdAction.setCheckable(True)
		self.displayMenu_horizontalAction = QAction(QIcon('./icon/horizontal.png'), _('Horizontal'), self)
		self.displayMenu_horizontalAction.setCheckable(True)
		self.displayMenu_transparencyAction = QAction(QIcon('./icon/transparency.png'), _('Transparency'), self)
		self.displayMenu_transparencyAction.setCheckable(True)
		self.displayMenu_topAction = QAction(QIcon('./icon/top.png'), _('Stay on top'), self)
		self.displayMenu_topAction.setCheckable(True)
		self.displayMenu_actionGroup.addAction(self.displayMenu_normalAction)
		self.displayMenu_actionGroup.addAction(self.displayMenu_fullscreenAction)
		self.displayMenu_actionGroup.addAction(self.displayMenu_osdAction)
		#self.displayMenu_actionGroup.addAction(self.displayMenu_widgetAction)
		self.displayMenu_actionGroup.addAction(self.displayMenu_horizontalAction)
		self.displayMenu_normalAction.setChecked(True)
		self.displayMenu.addActions(self.displayMenu_actionGroup.actions())
		self.displayMenu.addSeparator()
		self.displayMenu.addAction(self.displayMenu_topAction)
		self.displayMenu.addAction(self.displayMenu_transparencyAction)
		self.myMenu.addMenu(self.displayMenu)
		
		self.effectMenu = QMenu()
		self.effectMenu.setTitle(_('Set display effect'))
		self.effectMenu.setIcon(QIcon('./icon/effect.png'))
		self.effectMenu_actionGroup = QActionGroup(self)
		self.effectMenu_jumpAction = QAction(_('Jump'), self)
		self.effectMenu_jumpAction.setCheckable(True)
		self.effectMenu_rollAction = QAction(_('Switch scroll'), self)
		self.effectMenu_rollAction.setCheckable(True)
		self.effectMenu_alwaysRollAction = QAction(_('Always scroll'), self)
		self.effectMenu_alwaysRollAction.setCheckable(True)
		self.effectMenu_actionGroup.addAction(self.effectMenu_jumpAction)
		self.effectMenu_actionGroup.addAction(self.effectMenu_rollAction)
		self.effectMenu_actionGroup.addAction(self.effectMenu_alwaysRollAction)
		self.effectMenu.addActions(self.effectMenu_actionGroup.actions())
		self.myMenu.addMenu(self.effectMenu)
		
		self.openLrcEditorAction = QAction(QIcon('./icon/edit.png'), _('Lrc editor...'), self)
		self.myMenu.addAction(self.openLrcEditorAction)
		
		self.setSearchEngineAction = QAction(QIcon('./icon/engine.png'), _('Set search engine...'), self)
		self.myMenu.addAction(self.setSearchEngineAction)
		
		self.otherFunctionsMenu = QMenu()
		self.otherFunctionsMenu.setTitle(_('Other functions'))
		self.otherFunctionsMenu.setIcon(QIcon('./icon/function.png'))
		self.otherFunctionsMenu_searchAction = QAction(QIcon('./icon/search.png'), _('Search lrc on internet (fast)'), self)
		self.otherFunctionsMenu_searchAdvancedAction = QAction(QIcon('./icon/search_advance.png'), _('Search lrc on internet (advanced)...'), self)
		self.otherFunctionsMenu_cancelAction = QAction(QIcon('./icon/cancel.png'), _('Cancel current lrc'), self)
		self.otherFunctionsMenu_reloadAction = QAction(QIcon('./icon/reload.png'), _('Reload lrc'), self)
		
		self.otherFunctionsMenu_otherSetting = QAction(QIcon('./icon/configure.png'), _('Preference...'), self)
		
		self.otherFunctionsMenu_readUsltAction = QAction(QIcon('./icon/read_lrc.png'), _('Read lrc from media file'), self)
		self.otherFunctionsMenu_insertUsltAction = QAction(QIcon('./icon/insert_tag.png'), _('Write lrc into media file'), self)
		self.otherFunctionsMenu_deleteUsltAction = QAction(QIcon('./icon/del_tags.png'), _('Remove lrc from media file'), self)
		self.otherFunctionsMenu_deleteAllUsltAction = QAction(QIcon('./icon/del_all_tags.png'), _('Remove all embedded lrc'), self)
		self.otherFunctionsMenu.addAction(self.otherFunctionsMenu_reloadAction)
		self.otherFunctionsMenu.addAction(self.otherFunctionsMenu_cancelAction)
		self.otherFunctionsMenu.addAction(self.otherFunctionsMenu_searchAction)
		self.otherFunctionsMenu.addAction(self.otherFunctionsMenu_searchAdvancedAction)
		self.otherFunctionsMenu.addAction(self.otherFunctionsMenu_insertUsltAction)
		self.otherFunctionsMenu.addAction(self.otherFunctionsMenu_readUsltAction)
		self.otherFunctionsMenu.addAction(self.otherFunctionsMenu_deleteUsltAction)
		self.otherFunctionsMenu.addAction(self.otherFunctionsMenu_deleteAllUsltAction)
		self.otherFunctionsMenu.addAction(self.otherFunctionsMenu_otherSetting)
		self.myMenu.addMenu(self.otherFunctionsMenu)

		self.helpMenu = QMenu()
		self.helpMenu.setTitle(_('Help'))
		self.helpMenu.setIcon(QIcon('./icon/help.png'))
		self.viewHelpAction = QAction(QIcon('./icon/contents.png'), _('Help document...'), self)
		self.aboutQtAction = QAction(QIcon('./icon/qt.png'), _('About Qt...'), self)
		self.aboutAction = QAction(QIcon('./icon/lrcShow-X.png'), _('About lrcShow-X...'), self)
		self.helpMenu.addAction(self.viewHelpAction)
		self.helpMenu.addAction(self.aboutQtAction)
		self.helpMenu.addAction(self.aboutAction)
		self.myMenu.addMenu(self.helpMenu)
		
		self.closeAction = QAction(QIcon('./icon/exit.png'), _('Quit lrcShow-X'), self)
		self.myMenu.addAction(self.closeAction)
	
	def initSettingMenuBar(self): # init the fast setting bar
		self.toolMenuBar = QToolBar(self)
		pal = QPalette()
		pal.setColor(QPalette.Background, QColor(0, 0, 0, 0));
		self.toolMenuBar.setPalette(pal)
		self.toolMenuBar.addAction(self.lrcAdjustMenu_delayAction)
		self.toolMenuBar.addAction(self.lrcAdjustMenu_advancedAction)
		self.toolMenuBar.addAction(self.lrcAdjustMenu_saveToFileAction)
		self.toolMenuBar.addSeparator()
		self.toolMenuBar.addAction(self.playerControlMenu_playorpauseAction)
		self.toolMenuBar.addAction(self.playerControlMenu_stopAction)
		self.toolMenuBar.addAction(self.playerControlMenu_prevAction)
		self.toolMenuBar.addAction(self.playerControlMenu_nextAction)
		self.toolMenuBar.addSeparator()
		self.toolMenuBar.addAction(self.openLrcEditorAction)
		self.toolMenuBar.hide()
	
	def initIconTray(self):
		self.iconTray = QSystemTrayIcon(QIcon('./icon/lrcShow-X.png'), self)
		self.iconTray.setToolTip('lrcShow-X')
		self.iconTray.setContextMenu(self.myMenu)
	
	def contextMenuEvent(self,ev):# show the right click menu
		self.myMenu.popup(ev.globalPos())
	
	def mouseDoubleClickEvent(self,ev):# to show/hide the fast setting bar
		if(self.toolMenuBar.isHidden()):
			self.toolMenuBar.show()
		else:
			self.toolMenuBar.hide()
	
	def dragMoveEvent(self,ev):# disable this event
		pass
	
	def mouseReleaseEvent(self,ev):# disable this event
		pass